@@ -40,6 +40,7 @@ __all__ = (
     "EndpointTypeDef",
     "EngineDefaultsTypeDef",
     "EventCategoriesMapTypeDef",
+    "EventSubscriptionTypeDef",
     "EventTypeDef",
     "OrderableDBInstanceOptionTypeDef",
     "ParameterTypeDef",
@@ -51,6 +52,7 @@ __all__ = (
     "TagTypeDef",
     "UpgradeTargetTypeDef",
     "VpcSecurityGroupMembershipTypeDef",
+    "AddSourceIdentifierToSubscriptionResultTypeDef",
     "ApplyPendingMaintenanceActionResultTypeDef",
     "CertificateMessageTypeDef",
     "CloudwatchLogsExportConfigurationTypeDef",
@@ -61,6 +63,7 @@ __all__ = (
     "CreateDBClusterSnapshotResultTypeDef",
     "CreateDBInstanceResultTypeDef",
     "CreateDBSubnetGroupResultTypeDef",
+    "CreateEventSubscriptionResultTypeDef",
     "DBClusterMessageTypeDef",
     "DBClusterParameterGroupDetailsTypeDef",
     "DBClusterParameterGroupNameMessageTypeDef",
@@ -72,9 +75,11 @@ __all__ = (
     "DeleteDBClusterResultTypeDef",
     "DeleteDBClusterSnapshotResultTypeDef",
     "DeleteDBInstanceResultTypeDef",
+    "DeleteEventSubscriptionResultTypeDef",
     "DescribeDBClusterSnapshotAttributesResultTypeDef",
     "DescribeEngineDefaultClusterParametersResultTypeDef",
     "EventCategoriesMessageTypeDef",
+    "EventSubscriptionsMessageTypeDef",
     "EventsMessageTypeDef",
     "FailoverDBClusterResultTypeDef",
     "FilterTypeDef",
@@ -82,10 +87,12 @@ __all__ = (
     "ModifyDBClusterSnapshotAttributeResultTypeDef",
     "ModifyDBInstanceResultTypeDef",
     "ModifyDBSubnetGroupResultTypeDef",
+    "ModifyEventSubscriptionResultTypeDef",
     "OrderableDBInstanceOptionsMessageTypeDef",
     "PaginatorConfigTypeDef",
     "PendingMaintenanceActionsMessageTypeDef",
     "RebootDBInstanceResultTypeDef",
+    "RemoveSourceIdentifierFromSubscriptionResultTypeDef",
     "RestoreDBClusterFromSnapshotResultTypeDef",
     "RestoreDBClusterToPointInTimeResultTypeDef",
     "StartDBClusterResultTypeDef",
@@ -291,6 +298,23 @@ EventCategoriesMapTypeDef = TypedDict(
     "EventCategoriesMapTypeDef", {"SourceType": str, "EventCategories": List[str]}, total=False
 )
 
+EventSubscriptionTypeDef = TypedDict(
+    "EventSubscriptionTypeDef",
+    {
+        "CustomerAwsId": str,
+        "CustSubscriptionId": str,
+        "SnsTopicArn": str,
+        "Status": str,
+        "SubscriptionCreationTime": str,
+        "SourceType": str,
+        "SourceIdsList": List[str],
+        "EventCategoriesList": List[str],
+        "Enabled": bool,
+        "EventSubscriptionArn": str,
+    },
+    total=False,
+)
+
 EventTypeDef = TypedDict(
     "EventTypeDef",
     {
@@ -418,6 +442,12 @@ VpcSecurityGroupMembershipTypeDef = TypedDict(
     "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
 )
 
+AddSourceIdentifierToSubscriptionResultTypeDef = TypedDict(
+    "AddSourceIdentifierToSubscriptionResultTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
 ApplyPendingMaintenanceActionResultTypeDef = TypedDict(
     "ApplyPendingMaintenanceActionResultTypeDef",
     {"ResourcePendingMaintenanceActions": "ResourcePendingMaintenanceActionsTypeDef"},
@@ -472,6 +502,12 @@ CreateDBSubnetGroupResultTypeDef = TypedDict(
     "CreateDBSubnetGroupResultTypeDef", {"DBSubnetGroup": "DBSubnetGroupTypeDef"}, total=False
 )
 
+CreateEventSubscriptionResultTypeDef = TypedDict(
+    "CreateEventSubscriptionResultTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
 DBClusterMessageTypeDef = TypedDict(
     "DBClusterMessageTypeDef", {"Marker": str, "DBClusters": List["DBClusterTypeDef"]}, total=False
 )
@@ -530,6 +566,12 @@ DeleteDBInstanceResultTypeDef = TypedDict(
     "DeleteDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
 )
 
+DeleteEventSubscriptionResultTypeDef = TypedDict(
+    "DeleteEventSubscriptionResultTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
 DescribeDBClusterSnapshotAttributesResultTypeDef = TypedDict(
     "DescribeDBClusterSnapshotAttributesResultTypeDef",
     {"DBClusterSnapshotAttributesResult": "DBClusterSnapshotAttributesResultTypeDef"},
@@ -548,6 +590,12 @@ EventCategoriesMessageTypeDef = TypedDict(
     total=False,
 )
 
+EventSubscriptionsMessageTypeDef = TypedDict(
+    "EventSubscriptionsMessageTypeDef",
+    {"Marker": str, "EventSubscriptionsList": List["EventSubscriptionTypeDef"]},
+    total=False,
+)
+
 EventsMessageTypeDef = TypedDict(
     "EventsMessageTypeDef", {"Marker": str, "Events": List["EventTypeDef"]}, total=False
 )
@@ -576,6 +624,12 @@ ModifyDBSubnetGroupResultTypeDef = TypedDict(
     "ModifyDBSubnetGroupResultTypeDef", {"DBSubnetGroup": "DBSubnetGroupTypeDef"}, total=False
 )
 
+ModifyEventSubscriptionResultTypeDef = TypedDict(
+    "ModifyEventSubscriptionResultTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
 OrderableDBInstanceOptionsMessageTypeDef = TypedDict(
     "OrderableDBInstanceOptionsMessageTypeDef",
     {"OrderableDBInstanceOptions": List["OrderableDBInstanceOptionTypeDef"], "Marker": str},
@@ -596,6 +650,12 @@ RebootDBInstanceResultTypeDef = TypedDict(
     "RebootDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
 )
 
+RemoveSourceIdentifierFromSubscriptionResultTypeDef = TypedDict(
+    "RemoveSourceIdentifierFromSubscriptionResultTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
 RestoreDBClusterFromSnapshotResultTypeDef = TypedDict(
     "RestoreDBClusterFromSnapshotResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
 )
